@@ -12,6 +12,8 @@ namespace PHPUnit\Framework\MockObject;
 use function sprintf;
 
 /**
+ * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
+ *
  * @internal This class is not covered by the backward compatibility promise for PHPUnit
  */
 final class CannotUseOnlyMethodsException extends \PHPUnit\Framework\Exception implements Exception
@@ -20,7 +22,7 @@ final class CannotUseOnlyMethodsException extends \PHPUnit\Framework\Exception i
     {
         parent::__construct(
             sprintf(
-                'Trying to configure method "%s" with onlyMethods(), but it does not exist in class "%s". Use addMethods() for methods that do not exist in the class',
+                'Trying to configure method "%s" with onlyMethods(), but it does not exist in class "%s"',
                 $methodName,
                 $type,
             ),
