@@ -863,8 +863,9 @@ final class Generator
                 continue;
             }
 
-            $hasGetHook = false;
-            $hasSetHook = false;
+            $hasGetHook                 = false;
+            $hasSetHook                 = false;
+            $setHookMethodParameterType = null;
 
             if ($property->hasHook(PropertyHookType::Get) &&
                 !$property->getHook(PropertyHookType::Get)->isFinal()) {
@@ -873,7 +874,8 @@ final class Generator
 
             if ($property->hasHook(PropertyHookType::Set) &&
                 !$property->getHook(PropertyHookType::Set)->isFinal()) {
-                $hasSetHook = true;
+                $hasSetHook                 = true;
+                $setHookMethodParameterType = $mapper->fromParameterTypes($property->getHook(PropertyHookType::Set))[0]->type();
             }
 
             if (!$hasGetHook && !$hasSetHook) {
@@ -885,6 +887,7 @@ final class Generator
                 $mapper->fromPropertyType($property),
                 $hasGetHook,
                 $hasSetHook,
+                $setHookMethodParameterType,
             );
         }
 
