@@ -9,13 +9,14 @@
  */
 namespace PHPUnit\TextUI\Configuration;
 
+use function assert;
 use function count;
 use Iterator;
 
 /**
  * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
  *
- * @template-implements Iterator<int, IniSetting>
+ * @template-implements Iterator<non-negative-int, IniSetting>
  */
 final class IniSettingCollectionIterator implements Iterator
 {
@@ -23,6 +24,10 @@ final class IniSettingCollectionIterator implements Iterator
      * @var list<IniSetting>
      */
     private readonly array $iniSettings;
+
+    /**
+     * @var non-negative-int
+     */
     private int $position = 0;
 
     public function __construct(IniSettingCollection $iniSettings)
@@ -40,6 +45,9 @@ final class IniSettingCollectionIterator implements Iterator
         return $this->position < count($this->iniSettings);
     }
 
+    /**
+     * @return non-negative-int
+     */
     public function key(): int
     {
         return $this->position;
@@ -47,6 +55,8 @@ final class IniSettingCollectionIterator implements Iterator
 
     public function current(): IniSetting
     {
+        assert(isset($this->iniSettings[$this->position]));
+
         return $this->iniSettings[$this->position];
     }
 
