@@ -9,13 +9,14 @@
  */
 namespace PHPUnit\TextUI\Configuration;
 
+use function assert;
 use function count;
 use Iterator;
 
 /**
  * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
  *
- * @template-implements Iterator<int, TestDirectory>
+ * @template-implements Iterator<non-negative-int, TestDirectory>
  */
 final class TestDirectoryCollectionIterator implements Iterator
 {
@@ -23,6 +24,10 @@ final class TestDirectoryCollectionIterator implements Iterator
      * @var list<TestDirectory>
      */
     private readonly array $directories;
+
+    /**
+     * @var non-negative-int
+     */
     private int $position = 0;
 
     public function __construct(TestDirectoryCollection $directories)
@@ -40,6 +45,9 @@ final class TestDirectoryCollectionIterator implements Iterator
         return $this->position < count($this->directories);
     }
 
+    /**
+     * @return non-negative-int
+     */
     public function key(): int
     {
         return $this->position;
@@ -47,6 +55,8 @@ final class TestDirectoryCollectionIterator implements Iterator
 
     public function current(): TestDirectory
     {
+        assert(isset($this->directories[$this->position]));
+
         return $this->directories[$this->position];
     }
 
